@@ -17,7 +17,7 @@ import probabilities as prob
 from errors import ProbError
 
 
-def diss_integral_rigid_sphere(T, deg, idata, molecule, i, center_of_mass=True, nokt=False):
+def diss_integral_rigid_sphere(T, deg, idata, molecule, i, center_of_mass=True, vl_dependent=True, nokt=False):
     """Calculates the generalized dissociation omega integral either using the rigid sphere model or the rigid sphere
     model depending on the relative energy along the center-of-mass line
 
@@ -32,6 +32,8 @@ def diss_integral_rigid_sphere(T, deg, idata, molecule, i, center_of_mass=True,
     i - the vibrational level from which it dissociates
     center_of_mass - specifies the model being used (if False, the simpler rigid sphere model will be used, otherwise,
     the rigid sphere model depending on the relative energy along the center-of-mass line will be used)
+    vl_dependent - if True, the cross-section depends on the vibrational level of the dissociating molecule,
+    if False, the vibrational level is not taken into account; default value - True
     nokt - if False, then returns the usual generalized omega integral; if True, returns the generalized omega
     integral multiplied by (kT) ** (-0.5)
 
@@ -42,7 +44,10 @@ def diss_integral_rigid_sphere(T, deg, idata, molecule, i, center_of_mass=True,
         multiplier = constants.pi * (idata[1] ** 2) * ((constants.k * T / (2 * constants.pi * idata[0])) ** 0.5)
     else:
         multiplier = constants.pi * (idata[1] ** 2) * ((0.5 / (constants.pi * idata[0])) ** 0.5)
-    min_sq = (molecule.diss - molecule.vibr[i]) / (constants.k * T)
+    if vl_dependent is True:
+        min_sq = (molecule.diss - molecule.vibr[i]) / (constants.k * T)
+    else:
+        min_sq = molecule.diss / (constants.k * T)
     if deg == 0:
         if center_of_mass is False:
             return 0.5 * multiplier * np.exp(-min_sq)
@@ -287,8 +292,7 @@ def dE_rot_sq(T, molecule):
                    + molecule.rot_energy(j, 1) ** 2
                    + molecule.rot_energy(j - 1, 1) ** 2) * molecule.rot_exp(j, T)
     tmp += integrate.quad(f, 1, molecule.num_rot)[0]
-    tmp *= 0.5 / (molecule.Z_rot(T) * ((constants.k * T) ** 2)) / molecule.num_rot
-    return tmp
+    return tmp * 0.5 / (molecule.Z_rot(T) * ((constants.k * T) ** 2) * molecule.num_rot)
 
 
 def dE_rot_single(T, molecule):
@@ -306,8 +310,7 @@ def dE_rot_single(T, molecule):
     tmp = integrate.quad(f, 0, molecule.num_rot - 1)[0]
     f = lambda j: (molecule.rot_energy(j, 1) - molecule.rot_energy(j - 1, 1)) * molecule.rot_exp(j, T)
     tmp += integrate.quad(f, 1, molecule.num_rot)[0]
-    tmp *= 0.5 / (molecule.Z_rot(T) * ((constants.k * T))) / molecule.num_rot
-    return tmp
+    return tmp * 0.5 / (molecule.Z_rot(T) * constants.k * T * molecule.num_rot)
 
 
 def dE_rot_c_dE_rot_d(T, molecule1, molecule2):
