@@ -244,7 +244,7 @@ class Molecule_sts(object):
         j - rotational level (may be an np.array of indices, result will then be an array)
         T - the temperature of the mixture
         """
-        return ((2.0 * j + 1.0) / self.rot_symmetry) * np.exp(-self.rot[j] / (self.rot_symmetry * constants.k * T))
+        return ((2.0 * j + 1.0) / self.rot_symmetry) * np.exp(-self.rot[j] / (constants.k * T))
 
     def Z_rot(self, T):
         """Returns the rotational partition function Z_rot(T)
