@@ -4,7 +4,7 @@ __author__ = 'georgeoblapenko'
 
 import wtpoly
 import molecule
-import molecule_sts
+import particles
 import numpy as np
 import crosssection as cs_new
 import omegaint
@@ -13,7 +13,7 @@ from scipy import constants
 import matplotlib.pyplot as plt
 import loaddata
 
-N2 = molecule.Molecule('N2', 'anharmonic')
+N2 = particles.Molecule('N2', 'anharmonic')
 
 # print N2.diss
 #
